summaryrefslogtreecommitdiffstats
path: root/kmix/mdwslider.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmix/mdwslider.h')
-rw-r--r--kmix/mdwslider.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kmix/mdwslider.h b/kmix/mdwslider.h
index 01dd13aa..f55667ae 100644
--- a/kmix/mdwslider.h
+++ b/kmix/mdwslider.h
@@ -25,12 +25,12 @@
#include <kpanelapplet.h>
-#include <qvaluelist.h>
-#include <qwidget.h>
-#include <qlabel.h>
-#include <qptrlist.h>
-#include <qpixmap.h>
-#include <qrangecontrol.h>
+#include <tqvaluelist.h>
+#include <tqwidget.h>
+#include <tqlabel.h>
+#include <tqptrlist.h>
+#include <tqpixmap.h>
+#include <tqrangecontrol.h>
class QBoxLayout;
class QLabel;
@@ -61,7 +61,7 @@ public:
MDWSlider( Mixer *mixer, MixDevice* md,
bool showMuteLED, bool showRecordLED,
bool small, Qt::Orientation,
- QWidget* parent = 0, ViewBase* mw = 0, const char* name = 0);
+ TQWidget* parent = 0, ViewBase* mw = 0, const char* name = 0);
~MDWSlider() {}
void addActionToPopup( KAction *action );
@@ -74,11 +74,11 @@ public:
void setTicks( bool ticks );
void setIcons( bool value );
void setValueStyle( ValueStyle valueStyle );
- void setColors( QColor high, QColor low, QColor back );
- void setMutedColors( QColor high, QColor low, QColor back );
- QSize sizeHint() const;
- bool eventFilter( QObject* obj, QEvent* e );
- QSizePolicy sizePolicy() const;
+ void setColors( TQColor high, TQColor low, TQColor back );
+ void setMutedColors( TQColor high, TQColor low, TQColor back );
+ TQSize sizeHint() const;
+ bool eventFilter( TQObject* obj, TQEvent* e );
+ TQSizePolicy sizePolicy() const;
public slots:
void toggleRecsrc();
@@ -107,22 +107,22 @@ private slots:
void decreaseVolume();
private:
- QPixmap icon( int icontype );
+ TQPixmap icon( int icontype );
void setIcon( int icontype );
void createWidgets( bool showMuteLED, bool showRecordLED );
- void updateValue( QLabel *value, Volume::ChannelID chid );
+ void updateValue( TQLabel *value, Volume::ChannelID chid );
bool m_linked;
ValueStyle m_valueStyle;
- QLabel *m_iconLabel;
+ TQLabel *m_iconLabel;
KLedButton *m_muteLED;
KLedButton *m_recordLED;
- QWidget *m_label; // is either QLabel or VerticalText
- QBoxLayout *_layout;
- QPtrList<QWidget> m_sliders;
- QValueList<Volume::ChannelID> _slidersChids;
- QPtrList<QLabel> _numbers;
- // QValueList<Volume::ChannelID> _numbersChids;
+ TQWidget *m_label; // is either TQLabel or VerticalText
+ TQBoxLayout *_layout;
+ TQPtrList<TQWidget> m_sliders;
+ TQValueList<Volume::ChannelID> _slidersChids;
+ TQPtrList<TQLabel> _numbers;
+ // TQValueList<Volume::ChannelID> _numbersChids;
};
#endif